<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>过滤:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../../forms/fontdialog.ui" line="14"/>
        <location filename="../../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>选择终端字体</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>字体:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>字体大小:</translation>
    </message>
    <message>
        <location filename="../../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="330"/>
        <source>&amp;Close Tab</source>
        <translation>关闭标签页(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="232"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>水平布局终端(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="211"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>清空活动终端(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="235"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>垂直布局终端(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="240"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>折叠布局子终端(&amp;C)</translation>
    </message>
    <message>
        <source>N&amp;ext Subterminal</source>
        <translation type="vanished">弹出终端(&amp;E)</translation>
    </message>
    <message>
        <source>P&amp;revious Subterminal</source>
        <translation type="vanished">上个终端(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="218"/>
        <source>&amp;Next Tab</source>
        <translation>下个标签页(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="221"/>
        <source>&amp;Previous Tab</source>
        <translation>最前终端页(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="224"/>
        <source>Move Tab &amp;Left</source>
        <translation>往左边移动标签页(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="227"/>
        <source>Move Tab &amp;Right</source>
        <translation>往右边移动标签页(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <source>&amp;Top Subterminal</source>
        <translation>顶部子终端(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="246"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>底部子终端(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="249"/>
        <source>L&amp;eft Subterminal</source>
        <translation>左部子终端(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="252"/>
        <source>R&amp;ight Subterminal</source>
        <translation>右部子终端(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="259"/>
        <source>Copy &amp;Selection</source>
        <translation>复制选区(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="265"/>
        <source>Paste S&amp;election</source>
        <translation>粘贴选区(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="287"/>
        <source>&amp;Save Session</source>
        <translation>保存会话(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="293"/>
        <source>&amp;Load Session</source>
        <translation>载入会话(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="305"/>
        <source>Rename session</source>
        <translation>重命名会话</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="317"/>
        <source>New Tab From &amp;Preset</source>
        <translation>新标签窗口(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="318"/>
        <source>1 &amp;Terminal</source>
        <translation>单个终端窗口(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="320"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>水平分割为2(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="322"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>垂直分割为2(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="324"/>
        <source>4 Terminal&amp;s</source>
        <translation>分割4块(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="338"/>
        <source>&amp;Preferences...</source>
        <translation>参数配置(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="342"/>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="373"/>
        <source>Toggle Bookmarks</source>
        <translation>切换书签</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="381"/>
        <source>&amp;Bottom</source>
        <translation>下(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="382"/>
        <source>&amp;Top</source>
        <translation>上(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="383"/>
        <location filename="../../mainwindow.cpp" line="419"/>
        <source>&amp;Right</source>
        <translation>右(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="384"/>
        <location filename="../../mainwindow.cpp" line="420"/>
        <source>&amp;Left</source>
        <translation>左(&amp;L)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="402"/>
        <source>&amp;Tabs Layout</source>
        <translation>标签位置(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="418"/>
        <source>&amp;None</source>
        <translation>空(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="436"/>
        <source>S&amp;crollbar Layout</source>
        <translation>滚动条位置(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="449"/>
        <source>&amp;BlockCursor</source>
        <translation>块状光标(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="450"/>
        <source>&amp;UnderlineCursor</source>
        <translation>下划线状光标(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="451"/>
        <source>&amp;IBeamCursor</source>
        <translation>条状光标(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="468"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>光标样式(&amp;K)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="558"/>
        <source>Exit QTerminal</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="560"/>
        <source>Do not ask again</source>
        <translation>不要再次问我</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="568"/>
        <source>Are you sure you want to exit?</source>
        <translation>您真的要关闭本程序吗?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="598"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>轻量级多平台支持的终端模拟器</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="79"/>
        <source>Bookmarks</source>
        <translation>书签</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation type="vanished">重命名会话</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="171"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>按下&quot;%1&quot;显示该终端。</translation>
    </message>
    <message>
        <source>&amp;Clear Current Tab</source>
        <translation type="vanished">清理当前标签(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Paste Clip&amp;board</source>
        <translation>粘贴剪切板内容(&amp;B)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="268"/>
        <source>Zoom &amp;in</source>
        <translation>缩小(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="271"/>
        <source>Zoom &amp;out</source>
        <translation>放大(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="274"/>
        <source>Zoom rese&amp;t</source>
        <translation>重置大小(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="279"/>
        <source>&amp;Find...</source>
        <translation>搜索(&amp;F)...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="300"/>
        <source>&amp;Toggle Menu</source>
        <translation>下拉菜单(&amp;T)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="313"/>
        <source>&amp;New Tab</source>
        <translation>新建标签页(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="333"/>
        <source>&amp;New Window</source>
        <translation>新建窗口(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="348"/>
        <source>&amp;Hide Window Borders</source>
        <translation>隐藏窗口边框(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="359"/>
        <source>&amp;Show Tab Bar</source>
        <translation>显示标签栏(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="367"/>
        <source>Fullscreen</source>
        <translation>全屏显示</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="432"/>
        <source>Emulation</source>
        <translation>模拟器</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="62"/>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>终端设置</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="52"/>
        <source>Appearance</source>
        <translation>界面设置</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="57"/>
        <location filename="../../forms/propertiesdialog.ui" line="457"/>
        <source>Behavior</source>
        <translation>行为</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="67"/>
        <source>Dropdown</source>
        <translation>下拉菜单</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="100"/>
        <source>Color scheme</source>
        <translation>终端颜色</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="296"/>
        <source>Widget style</source>
        <translation>控件样式</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="110"/>
        <source>Scrollbar position</source>
        <translation>滚动栏位置</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="267"/>
        <source>Tabs position</source>
        <translation>标签页位置</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="319"/>
        <source>Show the menu bar</source>
        <translation>显示菜单栏</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="136"/>
        <source>Show a border around the current terminal</source>
        <translation>显示当前终端周围的边框</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="153"/>
        <source>Application transparency</source>
        <translation>透明设置</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="143"/>
        <source>Terminal transparency</source>
        <translation>终端透明度</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="120"/>
        <source>Start with preset:</source>
        <translation>默认配置:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="164"/>
        <source>None (single terminal)</source>
        <translation>为空或者单终端模式</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="169"/>
        <source>2 terminals horizontally</source>
        <translation>水平分割为2块</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="174"/>
        <source>2 terminals vertically</source>
        <translation>垂直分割为2块</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="179"/>
        <source>4 terminals</source>
        <translation>４分割为4块</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="218"/>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="326"/>
        <source>Keyboard cursor shape</source>
        <translation>光标样式</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="336"/>
        <source>Change window title based on current terminal</source>
        <translation>基于当前终端更改窗口标题</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="343"/>
        <source>Change window icon based on current terminal</source>
        <translation>基于当前终端更改窗口图标</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="350"/>
        <source>Enable bi-directional text support</source>
        <translation>开启双目录文本支持</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="357"/>
        <source>Background image:</source>
        <translation>背景图像:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="369"/>
        <source>Select</source>
        <translation>选择</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="378"/>
        <source>Show terminal size on resize</source>
        <translation>重新调整大小时显示终端大小</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="385"/>
        <source>Limit tab width:</source>
        <translation>限制标签宽度:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="395"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="405"/>
        <source>Show close button on each tab</source>
        <translation>在每个标签上显示关闭按钮</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="441"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;选择模拟模式。注意它不必符合您的操作系统。&lt;/p&gt;&lt;p&gt;选择 &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; 模拟模式会回退到最基础的功能模式。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="463"/>
        <source>Action after paste</source>
        <translation>粘贴之后的动作</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="473"/>
        <source>Confirm multiline paste</source>
        <translation>确认多行粘贴</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="480"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>修剪粘贴文本的最后空白行</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="513"/>
        <source>Open new terminals in current working directory</source>
        <translation>在当前工作路径打开新的终端</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="520"/>
        <source>Save Size when closing</source>
        <translation>关闭时保存窗口尺寸</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="527"/>
        <source>Save Position when closing</source>
        <translation>关闭时保存窗口位置</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="534"/>
        <source>Ask for confirmation when closing</source>
        <translation>关闭窗口需要确认</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="544"/>
        <source>Unlimited history</source>
        <translation>不限制历史记录条数</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="551"/>
        <source>History size (in lines)</source>
        <translation>历史记录大小 (行数)</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="558"/>
        <source>Default $TERM</source>
        <translation>默认 $TERM</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="572"/>
        <source>xterm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="577"/>
        <source>xterm-256color</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="649"/>
        <source>Height</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="659"/>
        <location filename="../../forms/propertiesdialog.ui" line="676"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="666"/>
        <source>Width</source>
        <translation>宽度</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="722"/>
        <source>Edit bookmark file contents</source>
        <translation>编辑书签文件内容</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="744"/>
        <source>Enable bookmarks</source>
        <translation>启用书签功能</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="753"/>
        <source>Bookmark file</source>
        <translation>书签文件</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="187"/>
        <location filename="../../forms/propertiesdialog.ui" line="280"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="614"/>
        <source>Shortcut</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="619"/>
        <source>Key</source>
        <translation>按键</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="72"/>
        <source>Bookmarks</source>
        <translation>书签</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="90"/>
        <source>Hide tab bar with only one tab</source>
        <translation>只有一个页面时隐藏标签栏</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="254"/>
        <source>&amp;Change...</source>
        <translation>修改设置(&amp;C)...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="631"/>
        <source>Show on start</source>
        <translation>启动时显示</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="638"/>
        <source>Size</source>
        <translation>尺寸</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="690"/>
        <source>Shortcut:</source>
        <translation>快捷键:</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="766"/>
        <source>Find...</source>
        <translation>搜索...</translation>
    </message>
    <message>
        <location filename="../../forms/propertiesdialog.ui" line="775"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>您可以指定书签保存位置，它很容易通过私有云或者Dropbox分享。</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <source>No scrollbar</source>
        <translation>无滚动栏</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="95"/>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="101"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>BlockCursor</source>
        <translation>块状光标</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>UnderlineCursor</source>
        <translation>下划线状光标</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="112"/>
        <source>IBeamCursor</source>
        <translation>条状光标</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>No move</source>
        <translation>无动作</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move start</source>
        <translation>开始移动</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="124"/>
        <source>Move end</source>
        <translation>移动完成</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="129"/>
        <location filename="../../propertiesdialog.cpp" line="199"/>
        <source>System Default</source>
        <translation>系统默认</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="282"/>
        <source>Choose a background image</source>
        <translation>选择背景图片</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="283"/>
        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
        <translation>图像 (*.bmp *.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../propertiesdialog.cpp" line="348"/>
        <source>Open or create bookmarks file</source>
        <translation>打开或者创建书签文件</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../../termwidget.cpp" line="237"/>
        <source>Show Details...</source>
        <translation>显示详细信息...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="110"/>
        <source>Local Bookmarks</source>
        <translation>本地书签</translation>
    </message>
    <message>
        <location filename="../../bookmarkswidget.cpp" line="168"/>
        <source>Synchronized Bookmarks</source>
        <translation>书签同步</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../../tabwidget.cpp" line="73"/>
        <location filename="../../tabwidget.cpp" line="219"/>
        <source>Shell No. %1</source>
        <translation>Shell No. %1</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="187"/>
        <source>Tab name</source>
        <translation>标签名</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="188"/>
        <source>New tab name:</source>
        <translation>新的标签名:</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="208"/>
        <source>Select new tab title color</source>
        <translation>选择新的标签标题颜色</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="229"/>
        <source>Close session</source>
        <translation>关闭会话</translation>
    </message>
    <message>
        <location filename="../../tabwidget.cpp" line="231"/>
        <source>Change title color</source>
        <translation>更改标题颜色</translation>
    </message>
    <message>
        <source>Rename session</source>
        <translation type="vanished">重命名会话</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../../termwidgetholder.cpp" line="78"/>
        <source>Load Session</source>
        <translation>载入会话</translation>
    </message>
    <message>
        <location filename="../../termwidgetholder.cpp" line="79"/>
        <source>List of saved sessions:</source>
        <translation>列出保存的会话:</translation>
    </message>
</context>
<context>
    <name>TermWidgetImpl</name>
    <message>
        <location filename="../../termwidget.cpp" line="229"/>
        <source>Paste multiline text</source>
        <translation>粘贴多行文本</translation>
    </message>
    <message>
        <location filename="../../termwidget.cpp" line="230"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>是否确认粘贴此文本？</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>动作(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>关于本程序(&amp;A)...</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>关于Qt(&amp;Q)...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation type="obsolete">参数配置(&amp;P)...</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>查看(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="vanished">退出(&amp;Q)</translation>
    </message>
</context>
</TS>
